.docker
.dockerignore
.env
.env.dev
.env.example
.env.test
.gitattributes
.github
.gitignore
CHANGELOG-1.0.md
CHANGELOG-1.1.md
Dockerfile
INSTALLATION GUIDE.md
LICENSE.txt
README.md
apps
bin
compose.override.yaml
compose.yaml
composer.json
composer.lock
config
migrations
phpunit.xml.dist
public
src
symfony.lock
templates
tests
translations
var
vendor
.htaccess